# Figure out our root directory
ROOTDIR=$(pwd)
unset CHROOT
if test "${ROOTDIR}" != "/"; then
 CHROOT="chroot ${ROOTDIR} "
  ROOTDIR="${ROOTDIR}/"
fi

GROUP_ID=42

# Set up groups.
if ! grep --quiet '^gdm:' etc/group ;then
  ${CHROOT} /usr/sbin/groupadd \
            -g ${GROUP_ID} \
            gdm 2> /dev/null
fi

# Set up user: add it if it doesn't exist, update it if it already does.
if OLD_ENTRY=$(grep --max-count=1 '^gdm:' etc/passwd) \
  || OLD_ENTRY=$(grep --max-count=1 \
  ':/var/lib/gdm:[a-z/]*$' etc/passwd)
then
  # Modify existing user
  OLD_USER=$(echo ${OLD_ENTRY} | cut --fields=1 --delimiter=':')
  USER_ID=$(echo ${OLD_ENTRY} | cut --fields=3 --delimiter=':')
  if test "${OLD_USER}" = "gdm"; then
    echo -n "Updating unprivileged user" 1>&2
  else
    echo -ne "Changing unprivileged user \e[1m${OLD_USER}\e[0m to" 1>&2
  fi
  ${CHROOT} /usr/sbin/usermod \
            -d '/var/lib/gdm' \
            -u ${USER_ID} \
            -s /bin/false \
            -g gdm \
            ${OLD_USER}
else
  # Add new user
  echo -n "Creating unprivileged user" 1>&2
  ${CHROOT} /usr/sbin/useradd \
            -c 'GDM' \
            -u ${GROUP_ID} \
            -g gdm \
            -s /bin/false \
            -d '/var/lib/gdm' \
            gdm 2> /dev/null
fi

if [ -x usr/bin/scrollkeeper-update ]; then
  ${CHROOT} /usr/bin/scrollkeeper-update -q > /dev/null 2>&1
fi
if [ -x /usr/bin/gtk-update-icon-cache ]; then
  ${CHROOT} /usr/bin/gtk-update-icon-cache -q usr/share/icons/hicolor > /dev/null 2>&1
fi

config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
## List of conf files to check.  The conf files in your package should end in .new
config etc/gdm/Xsession.new
config etc/gdm/custom.conf.new

# Fix permissions
${CHROOT} /bin/chown root.gdm /var/lib/gdm
${CHROOT} /bin/chmod 1770 /var/lib/gdm
${CHROOT} /bin/chown gdm.gdm /var/lib/gdm/.pulse 
${CHROOT} /bin/chmod 0700 /var/lib/gdm/.pulse
${CHROOT} /bin/chown gdm.gdm /var/lib/gdm/.pulse/default.pa
${CHROOT} /bin/chmod 0600 /var/lib/gdm/.pulse/default.pa

( cd usr/bin ; rm -rf gdmXnest )
( cd usr/bin ; ln -sf gdmXnestchooser gdmXnest )
